#include <batteryinfo.h>
#include <fstream>
#include <cmath>

namespace dlore
{
	std::string readData(std::filesystem::path path)
	{
		std::ifstream file(path, std::ios::in);
		if(!file) return "0";
		std::string ret;
		std::getline(file, ret);
		file.close();
		return ret;
	}

	BatteryInfo GetBatteryInfo(std::filesystem::path classPath)
	{
		BatteryInfo info;
		info.Manufacturer = readData(classPath / "manufacturer");
		info.Model = readData(classPath / "model_name");
		info.Technology = readData(classPath / "technology");

		info.Capacity = std::stoi(readData(classPath / "capacity"));
		info.ChargeNow = std::stoi(readData(classPath / "charge_now")) / 1000;
		info.ChargeFull = std::stoi(readData(classPath / "charge_full")) / 1000;
		info.ChargeFullDesign = std::stoi(readData(classPath / "charge_full_design")) / 1000;

		if(info.ChargeFullDesign != 0) {
			info.ChargeFullPercentageDesign = 100 * info.ChargeFull / info.ChargeFullDesign;
			info.CapacityDesign = 100 * info.ChargeNow / info.ChargeFullDesign;
		}

		int Vnow = std::stoi(readData(classPath / "voltage_now")) / 1000;
		int Vmin = std::stoi(readData(classPath / "voltage_min_design")) / 1000;

		info.Vnow = Vnow / 1000.0f;
		info.Vmin = Vmin / 1000.0f;

		info.CellSeriesCount = std::ceil(info.Vmin / 3.7f);
		// LiPo and Li-Ion cells operate at 3.7V (with the exception of LiFePO4 cells, which operate
		//                                        at 3.3V but are not used in laptops due to low voltage and charge)

		return info;
	}
}
